Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Eraser ¶
type Eraser struct {
// contains filtered or unexported fields
}
Eraser wraps a Stream removing position information from tokens
Commonly used for testing
type Parrot ¶
type Parrot struct {
// contains filtered or unexported fields
}
Parrot implements Stream by yielding tokens from supplied list
func FromTokens ¶
type Quiet ¶
type Quiet struct {
// contains filtered or unexported fields
}
Quiet wraps a Stream removing tokens with comments
Commonly used for testing
func NoComments ¶
Click to show internal directories.
Click to hide internal directories.